@@ -56,6 +56,7 @@ import org.apache.kafka.clients.consumer.KafkaConsumer;
 import org.apache.kafka.clients.producer.KafkaProducer;
 import org.apache.kafka.clients.producer.ProducerConfig;
 import org.apache.kafka.clients.producer.ProducerRecord;
+import org.apache.kafka.common.errors.UnknownTopicOrPartitionException;
 import org.apache.kafka.common.errors.WakeupException;
 import org.apache.kafka.common.serialization.ByteArrayDeserializer;
 import org.apache.kafka.common.serialization.ByteArraySerializer;
@@ -270,6 +271,7 @@ public class KafkaRpcServerManager {
             try {
                 consumer.subscribe(Arrays.asList(topic));
                 LOG.info("subscribed to topic {}", topic);
+
                 while (!closed.get()) {
                     ConsumerRecords<String, byte[]> records = consumer.poll(java.time.Duration.ofMillis(Long.MAX_VALUE));
                     for (ConsumerRecord<String, byte[]> record : records) {
@@ -330,6 +332,8 @@ public class KafkaRpcServerManager {
                 if (!closed.get()) {
                     throw e;
                 }
+            } catch (Exception e) {
+                LOG.error("Error in RPC consumer for topic '{}': {}", topic, e.getMessage(), e);
             } finally {
                 consumer.close();
             }
@@ -422,7 +426,13 @@ public class KafkaRpcServerManager {
 
             producer.send(producerRecord, (recordMetadata, e) -> {
                 if (e != null) {
-                    RATE_LIMITED_LOG.error(" RPC response {} with id {} couldn't be sent to Kafka", rpcMessage, rpcId, e);
+                    if (e instanceof UnknownTopicOrPartitionException) {
+                        RATE_LIMITED_LOG.error("Failed to send RPC response to topic '{}'. Topic does not exist. " +
+                                "If auto.create.topics.enable=false on the broker, ensure this topic is created manually. " +
+                                "RPC id: {}", topic, rpcId, e);
+                    } else {
+                        RATE_LIMITED_LOG.error("RPC response with id {} couldn't be sent to topic '{}': {}", rpcId, topic, e.getMessage(), e);
+                    }
                 } else {
                     if (LOG.isTraceEnabled()) {
                         LOG.trace("request with id {} executed, sending response {}, chunk number {} ", rpcId, responseAsString, chunkNum);
